Method: Addressable::URI.convert_path

Defined in:
lib/addressable/uri.rb

.convert_path(path) ⇒ Addressable::URI

Converts a path to a file scheme URI. If the path supplied is relative, it will be returned as a relative URI. If the path supplied is actually a non-file URI, it will parse the URI as if it had been parsed with Addressable::URI.parse. Handles all of the various Microsoft-specific formats for specifying paths.

Examples:

base = Addressable::URI.convert_path("/absolute/path/")
uri = Addressable::URI.convert_path("relative/path")
(base + uri).to_s
#=> "file:///absolute/path/relative/path"

Addressable::URI.convert_path(
  "c:\\windows\\My Documents 100%20\\foo.txt"
).to_s
#=> "file:///c:/windows/My%20Documents%20100%20/foo.txt"

Addressable::URI.convert_path("http://example.com/").to_s
#=> "http://example.com/"

Parameters:

  • path (String, Addressable::URI, #to_str)

    Typically a String path to a file or directory, but will return a sensible return value if an absolute URI is supplied instead.

Returns:

  • (Addressable::URI)

    The parsed file scheme URI or the original URI if some other URI scheme was provided.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/addressable/uri.rb', line 235

def self.convert_path(path)
  # If we were given nil, return nil.
  return nil unless path
  # If a URI object is passed, just return itself.
  return path if path.kind_of?(self)
  if !path.respond_to?(:to_str)
    raise TypeError, "Can't convert #{path.class} into String."
  end
  # Otherwise, convert to a String
  path = path.to_str.strip

  path.gsub!(/^file:\/?\/?/, EMPTY_STR) if path =~ /^file:\/?\/?/
  path = SLASH + path if path =~ /^([a-zA-Z])[\|:]/
  uri = self.parse(path)

  if uri.scheme == nil
    # Adjust windows-style uris
    uri.path.gsub!(/^\/?([a-zA-Z])[\|:][\\\/]/) do
      "/#{$1.downcase}:/"
    end
    uri.path.gsub!(/\\/, SLASH)
    if File.exists?(uri.path) &&
        File.stat(uri.path).directory?
      uri.path.gsub!(/\/$/, EMPTY_STR)
      uri.path = uri.path + '/'
    end

    # If the path is absolute, set the scheme and host.
    if uri.path =~ /^\//
      uri.scheme = "file"
      uri.host = EMPTY_STR
    end
    uri.normalize!
  end

  return uri
end